@@ -93,10 +93,6 @@ class Database(metaclass=Singleton):
         if "memory" in self.db_url:
             Base.metadata.drop_all(self._engine)
 
-    @property
-    def session(self) -> Session:
-        return self.session_factory()
-
 
 class TestContainer(containers.DeclarativeContainer):
     config = providers.Configuration(pydantic_settings=[TestConfig()])
@@ -128,16 +124,26 @@ def container():
     start_test_mappers()
     database = container.database.provided()
     database.create_database()
-    insert_initial_data(container)
+    insert_initial_data(database.session_factory())
 
     yield container
+
     container.reset_override()
     database.drop_all()
 
 
-def insert_initial_data(container):
-    session = container.database.provided().session
+@pytest.fixture(scope='function')
+def session(container):
+    s = container.database().session_factory()
+    s.rollback()
 
+    yield s
+
+    s.rollback()
+    s.close()
+
+
+def insert_initial_data(session):
     user_1 = User(
         username="test1",
         email="test@test.com",
@@ -191,25 +197,22 @@ def insert_initial_data(container):
 
 
 @pytest.fixture(scope="function")
-def user(container):
-    session = container.database.provided().session
+def user(container, session):
     return session.query(User).filter(User.username == "test1").first()
 
 
 @pytest.fixture(scope="function")
-def user_2(container):
-    session = container.database.provided().session
+def user_2(container, session):
     return session.query(User).filter(User.username == "test2").first()
 
 
 @pytest.fixture(scope="function")
-def user_without_role(container):
-    session = container.database.provided().session
+def user_without_role(container, session):
     return session.query(User).filter(User.username == "test3").first()
 
 
 @pytest.fixture(scope="function")
-def make_user(container):
+def make_user(container, session):
     def create_user(**overrides):
         default_data = {
             "username": fake.user_name(),
@@ -233,7 +236,6 @@ def make_user(container):
 
         user = User(**default_data)
 
-        session = container.database.provided().session
         session.add(user)
         session.commit()
 
@@ -243,6 +245,5 @@ def make_user(container):
 
 
 @pytest.fixture(scope="function")
-def vehicle(container):
-    session = container.database.provided().session
+def vehicle(container, session):
     return session.query(Vehicle).first()
