@@ -1,6 +1,7 @@
 import abc
-from typing import List
+from typing import Any
 
+from idp_authentication.enums import ChoiceEnum
 from idp_authentication.users.domain.entities.user import User
 
 
@@ -30,7 +31,12 @@ class UserRepositoryPort(RepositoryPort, abc.ABC):
     """User repository port."""
 
     @abc.abstractmethod
-    def get_users_with_access_to_records(self, *args, **kwargs) -> List[User]:
+    def get_users_with_access_to_records(
+        self,
+        app_entity_type: str,
+        record_identifier: Any,
+        roles: list[ChoiceEnum | str],
+    ) -> list[User]:
         """Get users with access to records."""
 
     @abc.abstractmethod
