@@ -1,4 +1,4 @@
-from abc import ABC
+from abc import ABC, abstractmethod
 
 from idp_authentication.users.domain.ports.repository import (
     UserRepositoryPort,
@@ -11,16 +11,18 @@ class UnitOfWorkPort(ABC):
     session: SessionPort
 
     def __enter__(self):
-        return self
+        """To implement"""
 
     def __exit__(self, *args):
-        self.rollback()
+        """To implement"""
 
+    @abstractmethod
     def commit(self):
-        self.session.commit()
+        """Commit"""
 
+    @abstractmethod
     def rollback(self):
-        self.session.rollback()
+        """Rollback"""
 
 
 class UsersUnitOfWorkPort(UnitOfWorkPort, ABC):
