@@ -1,9 +1,9 @@
-from .authorize_and_get_records_or_get_all_allowed import (
-    AuthorizeAndGetRecordsOrGetAllAllowedUseCase,
-)
 from .authorize_app_entity_records import AuthorizeEntityRecordsUseCase
+from .authorize_or_get_all_allowed_record_identifiers import (
+    AuthorizeOrGetAllAllowedRecordIdentifiersUseCase,
+)
 from .create_or_update_user import CreateOrUpdateUserUseCase
-from .get_allowed_app_entity_records import GetAllowedAppEntityRecordsUseCase
+from .get_allowed_records_identifiers import GetAllowedRecordIdentifiersUseCase
 from .get_user import GetUserUseCase
 from .get_users_with_access_to_app_entity_record import (
     GetUsersWithAccessToAppEntityRecordUseCase,
