@@ -15,8 +15,9 @@ class GetUsersWithAccessToAppEntityRecordUseCase(BaseUseCase):
         for role in roles:
             self._verify_role(role)
 
-        return self.users_unit_of_work.user_repository.get_users_with_access_to_records(
-            app_entity_type=app_entity_type,
-            record_identifier=record_identifier,
-            roles=roles,
-        )
+        with self.users_unit_of_work as uow:
+            return uow.user_repository.get_users_with_access_to_records(
+                app_entity_type=app_entity_type,
+                record_identifier=record_identifier,
+                roles=roles,
+            )
