@@ -10,7 +10,7 @@ class UserModel(Base, BaseModelMixin):
     __tablename__ = "users"
     __table_args__ = {"extend_existing": True}
     username = Column(String(100), nullable=False, unique=True)
-    email = Column(String(100), nullable=False, unique=True)
+    email = Column(String(100), nullable=False, unique=False)
     first_name = Column(String(100), nullable=False)
     last_name = Column(String(100), nullable=False)
     is_active = Column(Boolean, nullable=False, default=True)
@@ -18,3 +18,6 @@ class UserModel(Base, BaseModelMixin):
     is_staff = Column(Boolean, nullable=False, default=False)
     last_login = Column(DateTime, nullable=True)
     date_joined = Column(Date, nullable=True)
+
+    def __str__(self):
+        return f"{self.first_name} {self.last_name}"
