@@ -12,10 +12,11 @@ def test_create_user(container):
     assert created_user.username == data["username"]
 
     users_unit_of_work = container.users_module().users_unit_of_work()
-    inserted_user = users_unit_of_work.user_repository.get_or_none(
-        username=data["username"]
-    )
-    assert inserted_user is not None
+    with users_unit_of_work:
+        inserted_user = users_unit_of_work.user_repository.get_or_none(
+            username=data["username"]
+        )
+        assert inserted_user is not None
 
 
 def test_update_user(container, user):
@@ -33,5 +34,6 @@ def test_update_user(container, user):
     assert previous_user_email != updated_user.email
 
     users_unit_of_work = container.users_module().users_unit_of_work()
-    db_user = users_unit_of_work.user_repository.get_or_none(username=data["username"])
-    assert db_user.email == data["email"]
+    with users_unit_of_work as uow:
+        db_user = uow.user_repository.get_or_none(username=data["username"])
+        assert db_user.email == data["email"]
